-- Add the in built Cfilter plugin. Replaces QFGrep.
vim.cmd 'packadd cfilter'
vim.cmd 'packadd packer.nvim'

local init = function ()
  use {'wbthomason/packer.nvim', opt = true}
  -- Vertical Motion
  use 'phaazon/hop.nvim'
  -- Search
  use 'ibhagwan/fzf-lua'
  use 'bronson/vim-visual-star-search'
  -- Manage Project sessions
  use 'rmagatti/auto-session'
  -- Snippets
  use {
    'L3MON4D3/LuaSnip',
    requires = {
      'rafamadriz/friendly-snippets',
    }
  }
  -- Git support
  use 'lewis6991/gitsigns.nvim'
  use 'tpope/vim-fugitive'
  use 'ruifm/gitlinker.nvim'
  use 'whiteinge/diffconflicts'
  use 'junkblocker/patchreview-vim'
  -- Boost vim command line mode
  use 'vim-utils/vim-husk'
  -- Quickfix
  use {
    'https://gitlab.com/yorickpeterse/nvim-pqf',
    config = function()
      require('pqf').setup()
    end
  }
  -- Text Object plugins
  use {
    'wellle/targets.vim',
    'tpope/vim-surround',
    'tommcdo/vim-exchange',
    'chaoren/vim-wordmotion',
    'kana/vim-textobj-user',
    'kana/vim-textobj-entire',
    'idbrii/textobj-word-column.vim',
    'glts/vim-textobj-comment'
  }
  use 'numToStr/Comment.nvim'
  -- Tim pope essentials
  use {
    'tpope/vim-repeat',
    'tpope/vim-sleuth',
    'tpope/vim-dispatch'
  }
  -- Directory viewer
  use 'justinmk/vim-dirvish'
  --Toggle terminal
  use 'akinsho/toggleterm.nvim'
  -- Take care of sudo
  use 'lambdalisue/suda.vim'
  -- Alignment
  use 'junegunn/vim-easy-align'
  use 'nvim-lua/plenary.nvim'
  use 'jose-elias-alvarez/nvim-lsp-ts-utils'
  -- LSP
  use {
    'neovim/nvim-lspconfig',
    'kosayoda/nvim-lightbulb',
  }
  -- Language support & syntax highlighting
  use 'mfussenegger/nvim-lint'
  use 'simrat39/rust-tools.nvim'
  -- treesitter based syntax highlighting
  use {
    'nvim-treesitter/nvim-treesitter',
    requires = {
      {
        "nvim-treesitter/playground",
        after = "nvim-treesitter",
        cmd   = { "TSPlaygroundToggle", "TSHighlightCapturesUnderCursor" },
      },
      {
        "nvim-treesitter/nvim-treesitter-textobjects",
        module = "nvim-treesitter-textobjects",
        after = "nvim-treesitter",
      },
    },
    config = "require('treesitter')",
    run    = ':TSUpdate'
  }
  -- All writing needs
  use 'lervag/vimtex'
  -- Dhall
  use 'vmchale/dhall-vim'
  -- Marks and registers
  use {
    'chentau/marks.nvim',
  }
  use 'andymass/vim-matchup'
  use 'SmiteshP/nvim-gps'
end

return require('packer').startup(init)
